"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CreateIndexesTaskRunner = void 0;
var _listIndexes = require("./listIndexes");
var _createIndex = require("./createIndex");
var _listCreateElasticsearchIndexTaskPlugin = require("./listCreateElasticsearchIndexTaskPlugin");
class CreateIndexesTaskRunner {
  constructor(manager, indexManager) {
    this.manager = manager;
    this.indexManager = indexManager;
  }
  async execute(matching, done) {
    const plugins = (0, _listCreateElasticsearchIndexTaskPlugin.listCreateElasticsearchIndexTaskPlugin)(this.manager.context.plugins);
    if (plugins.length === 0) {
      return this.manager.response.done("No index plugins found.");
    }
    const indexes = await (0, _listIndexes.listIndexes)({
      context: this.manager.context,
      plugins
    });
    if (indexes.length === 0) {
      return this.manager.response.done("No indexes found.");
    }
    const isIndexAllowed = index => {
      if (typeof matching !== "string" || !matching) {
        return true;
      }
      return index.includes(matching);
    };
    const createIndex = (0, _createIndex.createIndexFactory)(this.indexManager);
    for (const {
      index,
      settings
    } of indexes) {
      if (this.manager.isAborted()) {
        return this.manager.response.aborted();
      } else if (this.manager.isCloseToTimeout()) {
        return this.manager.response.continue({
          done
        });
      }
      try {
        if (done.includes(index)) {
          continue;
        } else if (isIndexAllowed(index) === false) {
          continue;
        }
        const exists = await this.indexManager.indexExists(index);
        if (exists) {
          continue;
        }
        done.push(index);
        await createIndex.create(index, settings);
        await this.manager.store.addInfoLog({
          message: `Index "${index}" created.`,
          data: {
            index
          }
        });
      } catch (ex) {
        await this.manager.store.addErrorLog({
          message: `Failed to create index "${index}".`,
          error: ex
        });
      }
    }
    return this.manager.response.done("Indexes created.", {
      done
    });
  }
}
exports.CreateIndexesTaskRunner = CreateIndexesTaskRunner;

//# sourceMappingURL=CreateIndexesTaskRunner.js.map